import { Duration } from 'aws-cdk-lib';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ITopic } from 'aws-cdk-lib/aws-sns';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types/lambda-configuration';
/**
 * Properties for the EC2 Image Builder Start custom resource
 */
export interface Ec2ImageBuilderStartProps {
    /**
     * The ARN of the Image Builder pipeline to start.
     */
    readonly pipelineArn: string;
    /**
     * An optional user-generated hash value that will determine if the
     * construct will start the build pipeline. If this is not set, the pipeline
     * will only start once on initial deployment. By setting this, you can for
     * example start a new build if your build instructions have changed and
     * then wait for the pipeline to complete again.
     *
     * This hash should be a short
     * string, ideally ~7 characters or less. It will be set as the Physical ID
     * of the Custom Resource and also used to append to Waiter function
     * Physical IDs.
     */
    readonly hash?: string;
    /**
     * Set these properties to wait for the Image Build to complete. This is
     * useful if you need the AMI before your next infrastructure step.
     */
    readonly waitForCompletion?: Ec2ImageBuilderStart.WaitForCompletionProps;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
    /**
     * Optional KMS Encryption Key to use for encrypting resources.
     */
    readonly encryption?: IKey;
}
/**
 * Starts an EC2 Image Builder Pipeline and optionally waits for the build to
 * complete.
 *
 * This construct is useful if you want to create an image as part of your IaC
 * deployment. By waiting for completion of this construct, you can use the
 * image in the same deployment by retrieving the AMI and passing it to an EC2
 * build step.
 *
 * @example
 *
 * import { Duration } from 'aws-cdk-lib';
 * import { Topic } from 'aws-cdk-lib/aws-sns';
 * import { Ec2ImageBuilderStart } from '@cdklabs/cdk-proserve-lib/constructs';
 *
 * const topic = Topic.fromTopicArn(
 *   this,
 *   'MyTopic',
 *   'arn:aws:sns:us-east-1:123456789012:my-notification-topic'
 * );
 * new Ec2ImageBuilderStart(this, 'ImageBuilderStart', {
 *   pipelineArn:
 *     'arn:aws:imagebuilder:us-east-1:123456789012:image-pipeline/my-image-pipeline',
 *   waitForCompletion: {
 *     topic: topic,
 *     timeout: Duration.hours(7)  // wait up to 7 hours for completion
 *   }
 * });
 */
export declare class Ec2ImageBuilderStart extends Construct {
    /** The ARN of the image build version created by the pipeline execution */
    readonly imageBuildVersionArn: string;
    /** The underlying custom resource that starts the pipeline execution. */
    private readonly cr;
    /** The hash value supplied by the user or the default value (Run1x) */
    private readonly hash;
    /**
     * Starts an EC2 Image Builder Pipeline and optionally waits for the build
     * to complete.
     *
     * @param scope The construct scope
     * @param id The construct ID
     * @param props Configuration properties
     */
    constructor(scope: Construct, id: string, props: Ec2ImageBuilderStartProps);
    /**
     * Creates the AWS SDK call parameters to start the pipeline execution
     * @param id The construct ID
     * @param pipelineArn The ARN of the Image Builder pipeline to execute
     * @returns The AWS SDK call configuration
     */
    private start;
    private waitForTopicSignal;
}
export declare namespace Ec2ImageBuilderStart {
    interface WaitForCompletionProps {
        /**
         * An SNS Topic that will signal when the pipeline is complete. This is
         * typically configured on your EC2 Image Builder pipeline to trigger an
         * SNS notification when the pipeline completes.
         */
        readonly topic: ITopic;
        /**
         * The maximum amount of time to wait for the image build pipeline to
         * complete. This is set to a maximum of 12 hours by default.
         * @default 12 hours
         */
        readonly timeout?: Duration;
    }
}
