import { IKey } from 'aws-cdk-lib/aws-kms';
import { NodejsFunction } from 'aws-cdk-lib/aws-lambda-nodejs';
import { BucketProps } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types';
/**
 * Input metadata for the custom resource
 */
export interface FriendlyEmbraceProps {
    /**
     * Encryption key for protecting the Lambda environment
     */
    readonly encryption?: IKey;
    /**
     * Whether or not stacks in error state should be fatal to CR completion
     */
    readonly ignoreInvalidStates?: boolean;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
    /**
     * Optional S3 Bucket configuration settings.
     */
    readonly bucketConfiguration?: BucketProps;
}
/**
 * The Friendly Embrace construct can be used to remove CloudFormation stack
 * dependencies that are based on stack exports and imports.
 *
 * 🚨 WARNING: This construct is experimental and will directly modify
 * CloudFormation stacks in your CDK application via a Lambda-backed Custom
 * Resource. It is not recommended to use this construct in a production
 * environment.
 *
 * A custom resource that is designed to remove the "Deadly Embrace" problem that
 * occurs when you attempt to update a CloudFormation stack that is exporting
 * a resource used by another stack. This custom resource will run before all of
 * your stacks deploy/update and remove the dependencies by hardcoding each
 * export for all stacks that use it. For this reason, this construct should run
 * inside of its own stack and should be the last stack that is instantiated for
 * your application. That way the construct will be able to retrieve all of the
 * stacks from your CDK resource tree that it needs to update.
 *
 * > NOTE: You may need to add more permissions to the handler if the custom
 * resource cannot update your stacks. You can call upon the `handler` property
 * of the class to add more permissions to it.
 *
 * @example
 *
 * import { App, Stack } from 'aws-cdk-lib';
 * import { FriendlyEmbrace } from '@cdklabs/cdk-proserve-lib/constructs';
 *
 * const app = new App();
 * // ... other stack definitions
 * const embrace = new Stack(app, 'FriendlyEmbrace'); // last stack
 * new FriendlyEmbrace(embrace, 'FriendlyEmbrace'); // only construct in stack
 */
export declare class FriendlyEmbrace extends Construct {
    /**
     * Retrieves all the stacks in the CDK app (except the one to which this
     * Construct belongs)
     *
     * @param scope Parent to which the custom resource belongs
     * @returns All stacks in the CDK app except the scope
     */
    private static getOtherStacks;
    /**
     * Builds the worker to support the custom resource
     *
     * @param scope Parent to which the custom resource belongs
     * @param otherStacks All stacks in the CDK app except the scope
     * @param props Metadata for configuring the custom resource
     * @returns On event handler and service token for interacting with the
     * worker
     */
    private static buildProvider;
    /**
     * Translates the CDK construct properties to the custom resource
     * property format
     *
     * @param otherStacks CDK constructs for other stacks within the application
     * @param props Metadata for configuring the custom resource
     * @returns Input for the actual custom resource worker
     */
    private static createCustomResourceProperties;
    /**
     * Handler for the custom resource
     */
    readonly onEventHandler: NodejsFunction;
    /**
     * The Friendly Embrace construct can be used to remove CloudFormation stack
     * dependencies that are based on stack exports and imports.
     *
     * 🚨 WARNING: This construct is experimental and will directly modify
     * CloudFormation stacks in your CDK application via a Lambda-backed Custom
     * Resource. It is not recommended to use this construct in a production
     * environment.
     *
     * @param scope The scope in which to define this construct
     * @param id The construct ID
     * @param props Configuration properties
     */
    constructor(scope: Construct, id: string, props?: FriendlyEmbraceProps);
}
