import { IKey } from 'aws-cdk-lib/aws-kms';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { IParameter } from 'aws-cdk-lib/aws-ssm';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types';
/**
 * Properties for the IamServerCertificate construct.
 */
export interface IamServerCertificateProps {
    /**
     * Prefix to prepend to the AWS IAM Server Certificate name
     */
    readonly prefix: string;
    /**
     * AWS Systems Manager parameter or AWS Secrets Manager secret which contains the public certificate
     */
    readonly certificate: IamServerCertificate.ParameterProps | IamServerCertificate.SecretProps;
    /**
     * AWS Systems Manager parameter or AWS Secrets Manager secret which contains the private key
     */
    readonly privateKey: IamServerCertificate.ParameterProps | IamServerCertificate.SecretProps;
    /**
     * Encryption key for protecting the framework resources
     */
    readonly encryption?: IKey;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
}
/**
 * A construct that creates a Custom Resource to manage an AWS Identity and Access Management Server Certificate for
 * use in regions/partitions where AWS Certificate Manager is not available.
 *
 * This construct allows you to create an IAM Server Certificate using a certificate and private key stored in either
 * AWS Systems Manager Parameter Store or AWS Secrets Manager. It uses a Custom Resource to manage the lifecycle of the
 * server certificate.
 *
 * The construct also handles encryption for the framework resources using either a provided KMS key or an
 * AWS managed key.
 *
 * @example
 *
 * import { Key } from 'aws-cdk-lib/aws-kms';
 * import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 * import { StringParameter } from 'aws-cdk-lib/aws-ssm';
 * import { IamServerCertificate } from '@cdklabs/cdk-proserve-lib/constructs';
 *
 * const keyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-key-id';
 * const key = Key.fromKeyArn(this, 'Encryption', keyArn);
 *
 * const certificateData = StringParameter.fromSecureStringParameterAttributes(this, 'CertificateData', {
 *      parameterName: 'sample-parameter',
 *      encryptionKey: key
 * });
 *
 * const privateKeyData = Secret.fromSecretAttributes(this, 'PrivateKeySecret', {
 *      encryptionKey: key,
 *      secretCompleteArn: 'arn:aws:secretsmanager:us-east-1:111111111111:secret:PrivateKeySecret-aBc123'
 * });
 *
 * const certificate = new IamServerCertificate(this, 'ServerCertificate', {
 *      certificate: {
 *          parameter: certificateData,
 *          encryption: key
 *      },
 *      privateKey: {
 *          secret: privateKeyData,
 *          encryption: key
 *      },
 *      prefix: 'myapp'
 * });
 */
export declare class IamServerCertificate extends Construct {
    /**
     * Mapping of providers for each CDK stack
     * Used to ensure only one provider is created per stack
     */
    private static serviceTokens;
    /**
     * Builds the provider to support the Custom Resource
     *
     * @param scope Parent to which the Custom Resource belongs
     * @param props Metadata for configuring the Custom Resource
     *
     * @returns Provider for the worker
     */
    private static getOrBuildProvider;
    /**
     * Determines if the value for the Certificate/Private Key comes from AWS Secrets Manager
     * @param value Value for either the Certificate or Private Key
     * @returns True if the value comes from AWS Secrets Manager, false if it comes from AWS Systems Manager Parameter Store
     */
    private static isSecret;
    /**
     * Translates the CDK construct properties to the Custom Resource
     * property format
     * @param props Metadata for configuring the Custom Resource
     * @returns Input for the actual Custom Resource worker
     */
    private static createCustomResourceProperties;
    /**
     * ARN for the created AWS IAM Server Certificate
     */
    readonly arn: string;
    /**
     * Creates a new AWS IAM Server Certificate
     * @param scope Parent to which the Custom Resource belongs
     * @param id Unique identifier for this instance
     * @param props Metadata for configuring the Custom Resource
     */
    constructor(scope: Construct, id: string, props: IamServerCertificateProps);
    /**
     * Grants read permissions for an AWS Secrets Manager Secret and its KMS key if it is encrypted
     * @param policy IAM policy to add read permissions to
     * @param resources Secret and its optional encryption key
     */
    private grantReadForSecret;
}
export declare namespace IamServerCertificate {
    /**
     * Properties for a server certificate element regardless of where it is stored
     */
    interface ElementProps {
        /**
         * Optional encryption key that protects the secret
         */
        readonly encryption?: IKey;
    }
    /**
     * Properties for a server certificate element when it is stored in AWS Systems Manager Parameter Store
     */
    export interface ParameterProps extends ElementProps {
        /**
         * Reference to the AWS Systems Manager Parameter Store parameter that contains the data
         */
        readonly parameter: IParameter;
    }
    /**
     * Properties for a server certificate element when it is stored in AWS Secrets Manager
     */
    export interface SecretProps extends ElementProps {
        /**
         * Reference to the AWS Secrets Manager secret that contains the data
         */
        readonly secret: ISecret;
    }
    export {};
}
