import { ISubnet, IVpc } from 'aws-cdk-lib/aws-ec2';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ILogGroup, RetentionDays } from 'aws-cdk-lib/aws-logs';
import { CfnFirewall } from 'aws-cdk-lib/aws-networkfirewall';
import { Construct } from 'constructs';
import { AwsCustomResourceLambdaConfiguration } from '../../types';
/**
 * Properties for configuring a NetworkFirewall
 */
export interface NetworkFirewallProps {
    /**
     * Path to the Suricata rules file on the local file system
     */
    readonly suricataRulesFilePath: string;
    /**
     * The capacity to set for the Suricata rule group. This cannot be modified
     * after creation. You should set this to the upper bound of what you expect
     * your firewall rule group to consume.
     */
    readonly suricataRulesCapacity: number;
    /**
     * VPC where the Network Firewall will be deployed
     */
    readonly vpc: IVpc;
    /**
     * List of subnets where the Network Firewall will be placed
     * These should typically be dedicated firewall subnets
     */
    readonly firewallSubnets: ISubnet[];
    /**
     * Network Firewall routing configuration. By configuring these settings,
     * the Construct will automatically setup basic routing statements for you
     * for the provided subnets. This should be used with caution and you should
     * double check the routing is correct prior to deployment.
     */
    readonly configureVpcRoutes?: NetworkFirewall.NetworkFirewallVpcRouteProps;
    /**
     * Optional logging configuration for the Network Firewall. If not provided,
     * logs will not be written.
     */
    readonly logging?: NetworkFirewall.LoggingConfiguration;
}
/**
 * Creates an AWS Network Firewall using a user-supplied Suricata rules file in
 * a VPC.
 *
 * Follows guidelines that can be found at:
 * @see https://aws.github.io/aws-security-services-best-practices/guides/network-firewall/
 *
 * @example
 *
 * import { NetworkFirewall } from '@cdklabs/cdk-proserve-lib/constructs';
 *
 * new NetworkFirewall(this, 'Firewall', {
 *   vpc,
 *   firewallSubnets: vpc.selectSubnets({subnetGroupName: 'firewall'}).subnets,
 *   suricataRulesFilePath: './firewall-rules-suricata.txt',
 *   suricataRulesCapacity: 1000  // perform your own calculation based on the rules
 * });
 */
export declare class NetworkFirewall extends Construct {
    /**
     * The underlying CloudFormation Network Firewall resource
     */
    readonly firewall: CfnFirewall;
    /**
     * Creates an AWS Network Firewall using a user-supplied Suricata rules file
     * in a VPC.
     *
     * @param scope - Parent construct scope
     * @param id - Construct ID used to generate unique resource names
     * @param props - Network Firewall configuration properties
     */
    constructor(scope: Construct, id: string, props: NetworkFirewallProps);
    /**
     * Configures VPC routes for the Network Firewall
     *
     * Creates routes from protected subnets to the Network Firewall endpoint for all outbound traffic (0.0.0.0/0).
     * If return subnets are specified, also creates routes from those subnets back to the protected subnets via
     * the Network Firewall endpoint.
     *
     * @param props - Configuration for VPC routing including protected subnets and optional return subnets
     */
    private configureVpcRoutes;
}
export declare namespace NetworkFirewall {
    interface LoggingConfiguration {
        /** Log group to use for Network Firewall Logging. If not specified, a log group is created for you. The encryption key provided will be used to encrypt it if one was provided to the construct. */
        readonly logGroup?: ILogGroup;
        /** If you do not specify a log group, the amount of time to keep logs in the automatically created Log Group. Default: one week */
        readonly logRetention?: RetentionDays;
        /** The type of logs to write for the Network Firewall. This can be `TLS`, `FLOW`, or `ALERT`. */
        readonly logTypes: NetworkFirewall.LogType[];
        /**
         * Optional KMS key for encrypting Network Firewall logs
         */
        readonly encryption?: IKey;
    }
    enum LogType {
        /** Logs for events that are related to TLS inspection. For more information, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide . */
        TLS = "TLS",
        /** Standard network traffic flow logs. The stateful rules engine records flow logs for all network traffic that it receives. Each flow log record captures the network flow for a specific standard stateless rule group. */
        FLOW = "FLOW",
        /** Logs for traffic that matches your stateful rules and that have an action that sends an alert. A stateful rule sends alerts for the rule actions DROP, ALERT, and REJECT. For more information, see the StatefulRule property. */
        ALERT = "ALERT"
    }
    interface NetworkFirewallVpcRouteProps {
        /**
         * Subnets that will sit behind the network firewall and should have routes
         * to the Network Firewall. By supplying this parameter, routes will
         * be created for these subnets to the Network Firewall. Specify the
         * optional `destinationCidr` parameter if you want to restrict the
         * routes to a specific CIDR block. By default, routes will be created
         * for all outbound traffic (0.0.0.0/0) to the firewall.
         */
        readonly protectedSubnets: ISubnet[];
        /**
         * The destination CIDR block for the firewall (protectedSubnets) route.
         * If not specified, defaults to '0.0.0.0/0' (all IPv4 traffic).
         */
        readonly destinationCidr?: string;
        /**
         * Subnets that should have routes back to the protected subnets. Since
         * traffic is flowing through the firewall, routes should be put into the
         * subnets where traffic is returning to. This is most likely your public
         * subnets in the VPC. By supplying this parameter, routes will be created
         * that send all traffic destined for the `protectedSubnets` back to the
         * firewall for proper routing.
         */
        readonly returnSubnets?: ISubnet[];
        /**
         * Configuration for the Lambda function that will be used to retrieve info
         * about the AWS Network Firewall in order to setup the routing.
         */
        readonly lambdaConfiguration?: AwsCustomResourceLambdaConfiguration;
    }
}
