import { IKey } from 'aws-cdk-lib/aws-kms';
import { IDomain } from 'aws-cdk-lib/aws-opensearchservice';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { IParameter } from 'aws-cdk-lib/aws-ssm';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types';
/**
 * Properties for the OpenSearchAdminUser construct.
 */
export interface OpenSearchAdminUserProps {
    /**
     * The SSM parameter containing the username for the OpenSearch admin user.
     */
    readonly username: IParameter;
    /**
     * The SSM parameter or Secret containing the password for the OpenSearch admin user.
     */
    readonly credential: OpenSearchAdminUser.PasswordParameterProps | OpenSearchAdminUser.PasswordSecretProps;
    /**
     * The OpenSearch domain to which the admin user will be added.
     */
    readonly domain: IDomain;
    /**
     * Optional. The KMS key used to encrypt the OpenSearch domain.
     * If provided, the construct will grant the necessary permissions to use this key.
     */
    readonly domainKey?: IKey;
    /**
     * Optional. The KMS key used to encrypt the worker resources (e.g., Lambda function environment variables).
     * If provided, this key will be used for encryption; otherwise, an AWS managed key will be used.
     */
    readonly encryption?: IKey;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
}
/**
 * OpenSearchAdminUser construct creates a custom resource to manage an admin user for an Amazon OpenSearch domain.
 *
 * This construct creates a Lambda-backed custom resource that adds an admin user to the specified OpenSearch domain.
 * It uses the provided SSM parameter for the username, a provided SSM parameter or Secrets Manager secret for the
 * password, and sets up the necessary IAM permissions for the Lambda function to interact with the OpenSearch domain
 * and SSM parameter(s) and/or secret.
 *
 * The construct also handles encryption for the Lambda function's environment variables and dead letter queue,
 * using either a provided KMS key or an AWS managed key.
 *
 * @example
 *
 * import { Key } from 'aws-cdk-lib/aws-kms';
 * import { Domain } from 'aws-cdk-lib/aws-opensearchservice';
 * import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 * import { OpenSearchAdminUser } from '@cdklabs/cdk-proserve-lib/constructs';
 *
 * const keyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-key-id';
 * const key = Key.fromKeyArn(this, 'Encryption', keyArn);
 *
 * const adminCredential = StringParameter.fromSecureStringParameterAttributes(this, 'AdminCredential', {
 *      parameterName: 'sample-parameter',
 *      encryptionKey: key
 * });
 *
 * const domainKeyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-domain-key-id';
 * const domainKey = Key.fromKeyArn(this, 'DomainEncryption', domainKeyArn);
 * const domain = Domain.fromDomainEndpoint(this, 'Domain', 'vpc-testdomain.us-east-1.es.amazonaws.com');
 *
 * const adminUser = new OpenSearchAdminUser(this, 'AdminUser', {
 *      credential: {
 *          secret: adminCredential,
 *          encryption: key
 *      },
 *      domain: domain,
 *      domainKey: domainKey,
 *      username: 'admin'
 * });
 *
 */
export declare class OpenSearchAdminUser extends Construct {
    /**
     * Mapping of providers for each CDK stack
     */
    private static serviceTokens;
    /**
     * Builds the provider to support the custom resource
     *
     * @param scope Parent to which the custom resource belongs
     * @param props Metadata for configuring the custom resource
     *
     * @returns Provider for the worker
     */
    private static getOrBuildProvider;
    /**
     * Translates the CDK construct properties to the custom resource
     * property format
     * @param props Metadata for configuring the custom resource
     * @returns Input for the actual custom resource worker
     */
    private static createCustomResourceProperties;
    /**
     * Constructor
     * @param scope Parent to which the custom resource belongs
     * @param id Unique identifier for this instance
     * @param props Metadata for configuring the custom resource
     */
    constructor(scope: Construct, id: string, props: OpenSearchAdminUserProps);
}
export declare namespace OpenSearchAdminUser {
    /**
     * Properties for the admin user password regardless of where it is stored
     */
    interface PasswordCommonProps {
        /**
         * Optional encryption key that protects the secret
         */
        readonly encryption?: IKey;
    }
    /**
     * Properties for the admin user password specific to when the credential is stored in AWS Systems Manager Parameter Store
     */
    export interface PasswordParameterProps extends PasswordCommonProps {
        /**
         * Reference to the AWS Systems Manager Parameter Store parameter that contains the admin credential
         */
        readonly parameter: IParameter;
    }
    /**
     * Properties for the admin user password specific to when the credential is stored in AWS Secrets Manager
     */
    export interface PasswordSecretProps extends PasswordCommonProps {
        /**
         * Reference to the AWS Secrets Manager secret that contains the admin credential
         */
        readonly secret: ISecret;
    }
    export {};
}
