import { CfnComponent, CfnImageRecipe } from 'aws-cdk-lib/aws-imagebuilder';
import { ITopic } from 'aws-cdk-lib/aws-sns';
import { Construct } from 'constructs';
import { Ec2ImagePipeline, Ec2ImagePipelineBaseProps } from '../../constructs/ec2-image-pipeline';
/**
 * Properties for creating a Linux STIG Image Pipeline
 */
export interface Ec2LinuxImagePipelineProps extends Ec2ImagePipelineBaseProps {
    /**
     * The operating system to use for the image pipeline.
     */
    readonly operatingSystem?: Ec2LinuxImagePipeline.OperatingSystem;
    /**
     * Size for the root volume in GB. Default: 10 GB.
     * @default 10
     */
    readonly rootVolumeSize?: number;
    /**
     * A list of features to install.
     */
    readonly features?: Ec2LinuxImagePipeline.Feature[];
    /**
     * Additional EBS volume mappings to add to the image.
     * These will be added in addition to the root volume.
     */
    readonly extraDeviceMappings?: CfnImageRecipe.InstanceBlockDeviceMappingProperty[];
    /**
     * Additional components to install in the image.
     * These will be added after the default Linux components.
     */
    readonly extraComponents?: (Ec2ImagePipeline.Component | CfnComponent)[];
}
/**
 * A pattern to build an EC2 Image Pipeline specifically for Linux.
 *
 * This pattern contains opinionated code and features to help create a linux
 * pipeline. This pattern further simplifies setting up an image pipeline by
 * letting you choose specific operating systems and features.
 *
 * The example below shows how you can configure an image that contains the AWS
 * CLI and retains the SSM agent on the image. The image will have a 100GB root
 * volume.
 *
 * @example
 *
 * import { Ec2LinuxImagePipeline } from '@cdklabs/cdk-proserve-lib/patterns';
 *
 * new Ec2LinuxImagePipeline(this, 'ImagePipeline', {
 *   version: '0.1.0',
 *   operatingSystem:
 *     Ec2LinuxImagePipeline.OperatingSystem.RED_HAT_ENTERPRISE_LINUX_8_9,
 *   rootVolumeSize: 100,
 *     buildConfiguration: {
 *       start: true,
 *       waitForCompletion: true
 *     },
 *   features: [
 *     Ec2LinuxImagePipeline.Feature.AWS_CLI,
 *     Ec2LinuxImagePipeline.Feature.RETAIN_SSM_AGENT
 *   ]
 * );
 */
export declare class Ec2LinuxImagePipeline extends Construct {
    latestAmi: string | undefined;
    imagePipelineArn: string;
    imagePipelineTopic: ITopic;
    /**
     * A pattern to build an EC2 Image Pipeline specifically for Linux.
     *
     * @param scope The scope in which to define this construct
     * @param id The scoped construct ID
     * @param props Configuration properties
     */
    constructor(scope: Construct, id: string, props: Ec2LinuxImagePipelineProps);
    private getRootDeviceName;
    private buildComponents;
    private createComponentFromTemplate;
}
export declare namespace Ec2LinuxImagePipeline {
    enum Feature {
        AWS_CLI = "AWS_CLI",
        NICE_DCV = "NICE_DCV",
        RETAIN_SSM_AGENT = "RETAIN_SSM_AGENT",
        STIG = "STIG",
        SCAP = "SCAP"
    }
    enum OperatingSystem {
        RED_HAT_ENTERPRISE_LINUX_8_9 = "RED_HAT_ENTERPRISE_LINUX_8_9",
        AMAZON_LINUX_2 = "AMAZON_LINUX_2",
        AMAZON_LINUX_2023 = "AMAZON_LINUX_2023"
    }
}
